summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameSet.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWFrameSet.cpp')
-rw-r--r--kword/KWFrameSet.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kword/KWFrameSet.cpp b/kword/KWFrameSet.cpp
index 0e72f1681..d07a55e26 100644
--- a/kword/KWFrameSet.cpp
+++ b/kword/KWFrameSet.cpp
@@ -49,10 +49,10 @@ KWFrameSet::KWFrameSet( KWDocument *doc )
m_protectSize( false ),
m_anchorTextFs( 0L ), m_dcop( 0L ), m_pageManager( 0 )
{
// Send our "tqrepaintChanged" signals to the document.
setName("KWFrameSet");
if(m_doc) {
- connect( this, TQT_SIGNAL( tqrepaintChanged( KWFrameSet * ) ),
+ connect( this, TQT_SIGNAL( repaintChanged( KWFrameSet * ) ),
doc, TQT_SLOT( slotRepaintChanged( KWFrameSet * ) ) );
m_pageManager = doc->pageManager();
}
@@ -370,7 +370,7 @@ void KWFrameSet::setFixed()
for ( ; frameIt.current(); ++frameIt )
frameIt.current()->setZOrder( m_doc->maxZOrder( frameIt.current()->pageNumber(m_doc) ) + 1 );
- m_doc->tqrepaintAllViews();
+ m_doc->repaintAllViews();
m_doc->updateRulerFrameStartEnd();
}
@@ -399,7 +399,7 @@ void KWFrameSet::createAnchors( KoTextParag * parag, int index, bool placeHolder
}
parag->setChanged( true );
if ( tqrepaint )
- emit tqrepaintChanged( m_anchorTextFs );
+ emit repaintChanged( m_anchorTextFs );
}
void KWFrameSet::deleteAnchor( KWAnchor * anchor )
@@ -437,7 +437,7 @@ void KWFrameSet::deleteAnchors()
KWAnchor * anchor = findAnchor( frameNum );
deleteAnchor( anchor );
}
- emit tqrepaintChanged( textfs );
+ emit repaintChanged( textfs );
}
void KWFrameSet::moveFloatingFrame( int frameNum, const KoPoint &position )
@@ -49,10 +49,10 @@ KWFrameSet::KWFrameSet( KWDocument *doc )
m_anchorTextFs( 0L ), m_dcop( 0L ), m_pageManager( 0 )
{
- // Send our "tqrepaintChanged" signals to the document.
+ // Send our "repaintChanged" signals to the document.
setName("KWFrameSet");
if(m_doc) {